@@ -17,7 +17,7 @@
 ## from Larry Wall's metaconfig.
 ##-------------------------------------------------------
 
-PATH='.:/bin:/usr/bin'
+PATH=".:/bin:/usr/bin:/usr/local/bin:$PATH"
 export PATH || (echo 'You must use sh to run this script'; kill $$)
 if [ ! -t 0 ] ; then
 	echo "Say 'sh install.sh', not 'sh < install.sh'"
@@ -42,18 +42,6 @@ else
 	c=""
 fi
 
-##-------------------------------------------------------
-## Better have a copy of tar!
-## If /bin/sh does not exist or is not readable (seems
-## fairly unlikely), then this will fail.
-##-------------------------------------------------------
-
-(tar cvf /dev/null /bin/sh) 2> /dev/null 1>&2
-if [ $? -ne 0 ]; then
-    echo "tar command not found -- aborting install."
-	exit 1
-fi
-
 ##-------------------------------------------------------
 ## Can't live without sed.
 ##-------------------------------------------------------
@@ -78,52 +66,24 @@ for p in $awknames; do
 	fi
 done
 
-##-------------------------------------------------------
-## Does this system have a copy of grep we can use?
-## Some greps don't return status (amazing, huh?),
-## so we look for a copy of grep that
-## returns 0 status for an exact match
-## returns 0 status for a case-insensitive match
-## returns 0 status for a wildcard match
-## returns non-zero status for a failed match
-##-------------------------------------------------------
-
-GREP=""
-grepnames="grep egrep"
-lcgrepstr="findensiemich"     # all lower case
-mcgrepstr="FindenSieMich"     # mixed case
-wcgrepstr="sie.ich$"          # wild card match
-nogrepstr="WoBistDu"          # should not be able to find this
-for p in $grepnames; do
-	(echo "$lcgrepstr" | $p "$lcgrepstr") 2> /dev/null 1>&2
-	if [ $? -eq 0 ]; then
-		(echo "$lcgrepstr" | $p -i "$mcgrepstr") 2> /dev/null 1>&2
-		if [ $? -eq 0 ]; then
-			(echo "$lcgrepstr" | $p "$wcgrepstr") 2> /dev/null 1>&2
-			if [ $? -eq 0 ]; then
-				(echo "$lcgrepstr" | $p "$nogrepstr") 2> /dev/null 1>&2
-				if [ $? -ne 0 ]; then
-					GREP=$p
-					break
-				fi
-			fi
-		fi
-	fi
-done
-
 ##-------------------------------------------------------
 ## Does this system have a pager that we can use?
 ## Use cat if desperate.
 ##-------------------------------------------------------
 
 MORE="cat"
-morenames="more less cat"
+morenames="less more most pg cat"
 for p in $morenames; do
-	($p $0 < /dev/null) 2> /dev/null 1>&2
-	if [ $? -eq 0 ]; then
-		MORE=$p
-		break
-	fi
+    pagerpath=`command -v $p`
+
+    if [ -z $pagerpath ]; then
+        continue
+    fi
+
+    if [ -x $pagerpath ]; then
+        MORE=$pagerpath
+        break
+    fi
 done
 
 ##-------------------------------------------------------
@@ -243,9 +203,8 @@ cat << END_OF_TEXT
 Installer program for:
 Tripwire(R) 2.4 Open Source
 
-Copyright (C) 1998-2000 Tripwire (R) Security Systems, Inc.  Tripwire (R)
-is a registered trademark of the Purdue Research Foundation and is
-licensed exclusively to Tripwire (R) Security Systems, Inc.
+Copyright (C) 1998-2017 Tripwire, Inc.
+Tripwire is a registered trademark of Tripwire, Inc. All rights reserved.
 
 END_OF_TEXT
 
@@ -417,15 +376,21 @@ else
 ##-------------------------------------------------------
 ## Verify that the specified editor program exists
 ##-------------------------------------------------------
- 
-TWEDITOR=${TWEDITOR:-'/bin/vi'}
+
+DEFAULTEDITOR=${EDITOR:-‘/bin/vi’}
+TWEDITOR=${TWEDITOR:-$DEFAULTEDITOR}
+TWEDITOR_PATH=`command -v $TWEDITOR`
+
+if [ -n ${TWEDITOR_PATH} ]; then
+    TWEDITOR=$TWEDITOR_PATH
+fi
 
 if [ -x ${TWEDITOR} ]; then
-        echo "${TWEDITOR} exists.  Continuing installation."
-        echo
+    echo "${TWEDITOR} exists.  Continuing installation."
+    echo
 else
-        echo "${TWEDITOR} does not exist.  Exiting."
-        exit 1
+    echo "${TWEDITOR} not found. Continuing, but your configuration may need to be edited after installation."
+    echo
 fi
 
 ##-------------------------------------------------------
@@ -584,9 +549,12 @@ f10=' ff=${POLICYSRC} ; d="/policy" ; dd=$TWPOLICY ; rr=0640 '
 #f16=' ff=twadmin.8 ; d="/man/man8" ; dd=$TWMAN/man8 ; rr=0444 '
 #f17=' ff=twintro.8 ; d="/man/man8" ; dd=$TWMAN/man8 ; rr=0444 '
 #f18=' ff=twprint.8 ; d="/man/man8" ; dd=$TWMAN/man8 ; rr=0444 '
+f19=' ff=COMMERCIAL ; d="" ; dd=$TWDOCS ; rr=0444 '
+f20=' ff=ReadMe-2.4.3 ; d="" ; dd=$TWDOCS ; rr=0444 '
+f21=' ff=ChangeLog ; d="" ; dd=$TWDOCS ; rr=0444 '
 
 # Binaries and manpages are already installed by the install target
-loosefiles="f3 f4 f5 f6 f7 f8 f9 f10"
+loosefiles="f3 f4 f5 f6 f7 f8 f9 f10 f19 f20 f21"
 
 for i in $loosefiles; do
 	eval "eval \"\$$i\""
@@ -607,7 +575,9 @@ done
 
 if [ -n "$INSTALL_STRIP_FLAG" ] ; then
   echo "INSTALL_STRIP_FLAG is set, stripping binaries"
-  strip "$TWBIN/siggen" "$TWBIN/tripwire" "$TWBIN/twadmin" "$TWBIN/twprint" 
+  chmod u+w "$TWBIN/siggen" "$TWBIN/tripwire" "$TWBIN/twadmin" "$TWBIN/twprint"
+  strip "$TWBIN/siggen" "$TWBIN/tripwire" "$TWBIN/twadmin" "$TWBIN/twprint"
+  chmod u-w "$TWBIN/siggen" "$TWBIN/tripwire" "$TWBIN/twadmin" "$TWBIN/twprint"
 fi
 
 #Make extra sure we don't install the unit test binary to sbin
@@ -923,7 +893,7 @@ cat << END_OF_TEXT
 ----------------------------------------------
 The installation succeeded.
 
-Please refer to $README_LOC
+Please refer to documentation in $TWDOCS
 for release information and to the printed user documentation
 for further instructions on using Tripwire 2.4 Open Source.
 
