@@ -90,7 +90,7 @@ void cIntegrityCheck::ProcessAddedFCO( cDbDataSourceIter dbIter, iFCODataSourceI
                 // to done...
                 //
                 while( ! dbIter.Done() ) dbIter.Next();
-                std::auto_ptr<iFCODataSourceIter> pCopy( pIter->CreateCopy() );
+                TW_UNIQUE_PTR<iFCODataSourceIter> pCopy( pIter->CreateCopy() );
                 ProcessDir( dbIter, pCopy.get() );
             }
         }
@@ -231,7 +231,7 @@ void cIntegrityCheck::ProcessChangedFCO( cDbDataSourceIter dbIter, iFCODataSourc
     {
         if( pIter->CanDescend() || dbIter.CanDescend() )
         {
-            std::auto_ptr<iFCODataSourceIter> pCopy( pIter->CreateCopy() );
+            TW_UNIQUE_PTR<iFCODataSourceIter> pCopy( pIter->CreateCopy() );
             ProcessDir( dbIter, pCopy.get() );
         }
     }
@@ -353,12 +353,15 @@ void cIntegrityCheck::ProcessDir( cDbDataSourceIter dbIter, iFCODataSourceIter*
         if( dbIter.Done() )
         {
             ASSERT( pIter != 0);
-            d.TraceDetail( "Examining <done> and %s\n", pIter->GetName().AsString().c_str() );
-            //
-            // these are all new entries, add them to the "Added" set...
-            //
-            ProcessAddedFCO( dbIter, pIter );
-            pIter->Next();
+            if (pIter)
+            {
+                d.TraceDetail( "Examining <done> and %s\n", pIter->GetName().AsString().c_str() );
+                //
+                // these are all new entries, add them to the "Added" set...
+                //
+                ProcessAddedFCO( dbIter, pIter );
+                pIter->Next();
+            }
         }
         else if( ! pIter )
         {
@@ -450,7 +453,7 @@ void cIntegrityCheck::Execute( uint32 flags )
     mFlags = flags;
     // create the data source iterator
     //
-    std::auto_ptr<iFCODataSourceIter>   pDSIter(iTWFactory::GetInstance()->CreateDataSourceIter());
+    TW_UNIQUE_PTR<iFCODataSourceIter>   pDSIter(iTWFactory::GetInstance()->CreateDataSourceIter());
     //
     // set up the database's iterator...
     // I assume the current genre is correct...
@@ -557,7 +560,7 @@ void cIntegrityCheck::ExecuteOnObjectList( const std::list<cFCOName>& fcoNames,
     //
     // create the data source iterator
     //
-    std::auto_ptr<iFCODataSourceIter>   pDSIter(iTWFactory::GetInstance()->CreateDataSourceIter());
+    TW_UNIQUE_PTR<iFCODataSourceIter>   pDSIter(iTWFactory::GetInstance()->CreateDataSourceIter());
     //
     // set up the database's iterator...
     // I assume the current genre is correct...
@@ -590,7 +593,7 @@ void cIntegrityCheck::ExecuteOnObjectList( const std::list<cFCOName>& fcoNames,
     // iterate over all the objects to integrity check..
     //
     std::list<cFCOName>::const_iterator it;
-    for( it = fcoNames.begin(); it != fcoNames.end(); it++ )
+    for( it = fcoNames.begin(); it != fcoNames.end(); ++it )
     {
         TW_NOTIFY_VERBOSE(  _T("%s%s\n"), 
                             TSS_GetString( cTripwire, tripwire::STR_NOTIFY_CHECKING ).c_str(),
